==> haskell-safe-0.3.15-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-safe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe
version: 0.3.15
id: safe-0.3.15-2Yd45VWFfdcKqKyispOifY
key: safe-0.3.15-2Yd45VWFfdcKqKyispOifY
license: BSD3
copyright: Neil Mitchell 2007-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/safe#readme
synopsis: Library of safe (exception free) functions
description:
    A library wrapping @Prelude@/@Data.List@ functions that can throw exceptions, such as @head@ and @!!@.
    Each unsafe function has up to four variants, e.g. with @tail@:
    .
    * @tail :: [a] -> [a]@, raises an error on @tail []@.
    .
    * @tailMay :: [a] -> /Maybe/ [a]@, turns errors into @Nothing@.
    .
    * @tailDef :: /[a]/ -> [a] -> [a]@, takes a default to return on errors.
    .
    * @tailNote :: /String/ -> [a] -> [a]@, takes an extra argument which supplements the error message.
    .
    * @tailSafe :: [a] -> [a]@, returns some sensible default if possible, @[]@ in the case of @tail@.
    .
    This package is divided into three modules:
    .
    * "Safe" contains safe variants of @Prelude@ and @Data.List@ functions.
    .
    * "Safe.Foldable" contains safe variants of @Foldable@ functions.
    .
    * "Safe.Exact" creates crashing versions of functions like @zip@ (errors if the lists are not equal) and @take@ (errors if there are not enough elements), then wraps them to provide safe variants.
category: Unclassified
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Safe Safe.Exact Safe.Foldable Safe.Partial
hidden-modules: Safe.Util
abi: 730faa4a20cdc6fcdac85a353918ae46
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/safe-0.3.15
library-dirs: /usr/lib/ghc-8.0.2/site-local/safe-0.3.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/safe-0.3.15
hs-libraries: HSsafe-0.3.15-2Yd45VWFfdcKqKyispOifY
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-safe/html/safe.haddock
haddock-html: /usr/share/doc/haskell-safe/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safe-0.3.15-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-safe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe
version: 0.3.15
id: safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
key: safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
license: BSD3
copyright: Neil Mitchell 2007-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/safe#readme
synopsis: Library of safe (exception free) functions
description:
    A library wrapping @Prelude@/@Data.List@ functions that can throw exceptions, such as @head@ and @!!@.
    Each unsafe function has up to four variants, e.g. with @tail@:
    .
    * @tail :: [a] -> [a]@, raises an error on @tail []@.
    .
    * @tailMay :: [a] -> /Maybe/ [a]@, turns errors into @Nothing@.
    .
    * @tailDef :: /[a]/ -> [a] -> [a]@, takes a default to return on errors.
    .
    * @tailNote :: /String/ -> [a] -> [a]@, takes an extra argument which supplements the error message.
    .
    * @tailSafe :: [a] -> [a]@, returns some sensible default if possible, @[]@ in the case of @tail@.
    .
    This package is divided into three modules:
    .
    * "Safe" contains safe variants of @Prelude@ and @Data.List@ functions.
    .
    * "Safe.Foldable" contains safe variants of @Foldable@ functions.
    .
    * "Safe.Exact" creates crashing versions of functions like @zip@ (errors if the lists are not equal) and @take@ (errors if there are not enough elements), then wraps them to provide safe variants.
category: Unclassified
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Safe Safe.Exact Safe.Foldable Safe.Partial
hidden-modules: Safe.Util
abi: 6cf1fe7158a61976010b5254caed2ddd
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/safe-0.3.15
library-dirs: /usr/lib/ghc-8.2.1/site-local/safe-0.3.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/safe-0.3.15
hs-libraries: HSsafe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-safe/html/safe.haddock
haddock-html: /usr/share/doc/haskell-safe/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
